$:.unshift(File.dirname(__FILE__))
require 'mailaccounts.rb'
require 'mailaccountsMappingRegistry.rb'
require 'soap/rpc/driver'

class UtilsSoapPort < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "https://admin.excedent.com/mailaccounts/mailaccounts.ASP"
  NsMessage = "http://admin.excedent.com/mailaccounts/message/"

  Methods = [
    [ XSD::QName.new(NsMessage, "GetDomainSettings"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSettings",
      "getDomainSettings",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Aliases", ["::SOAP::SOAPString"]],
        [:in, "MaxMbxSize", ["::SOAP::SOAPInt"]],
        [:in, "MaxNumUsers", ["::SOAP::SOAPInt"]],
        [:in, "AllowWirelessAccess", ["::SOAP::SOAPShort"]],
        [:in, "AdminUsername", ["::SOAP::SOAPString"]],
        [:in, "AdminPassword", ["::SOAP::SOAPString"]],
        [:retval, "Aliases", ["::SOAP::SOAPString"]],
        [:out, "MaxMbxSize", ["::SOAP::SOAPInt"]],
        [:out, "MaxNumUsers", ["::SOAP::SOAPInt"]],
        [:out, "AllowWirelessAccess", ["::SOAP::SOAPShort"]],
        [:out, "AdminUsername", ["::SOAP::SOAPString"]],
        [:out, "AdminPassword", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainStats"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainStats",
      "getDomainStats",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "numUsers", ["::SOAP::SOAPInt"]],
        [:in, "DiskSpace", ["::SOAP::SOAPDouble"]],
        [:retval, "numUsers", ["::SOAP::SOAPInt"]],
        [:out, "DiskSpace", ["::SOAP::SOAPDouble"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainNumUsers"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainNumUsers",
      "getDomainNumUsers",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "numUsers", ["::SOAP::SOAPInt"]],
        [:retval, "numUsers", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainNumUsersActive"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainNumUsersActive",
      "getDomainNumUsersActive",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPString"]],
        [:in, "numUsers", ["::SOAP::SOAPInt"]],
        [:retval, "numUsers", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainNumUserAliases"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainNumUserAliases",
      "getDomainNumUserAliases",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "numAliases", ["::SOAP::SOAPInt"]],
        [:retval, "numAliases", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainMXRecords"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainMXRecords",
      "getDomainMXRecords",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "MxRecordArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "MxRecordArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAllDomains"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAllDomains",
      "getAllDomains",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostNameArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "HostNameArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAllDomainsStats"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAllDomainsStats",
      "getAllDomainsStats",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostnameStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "HostnameStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAllDomainsSettings"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAllDomainsSettings",
      "getAllDomainsSettings",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostnameSettingArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "HostnameSettingArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAllDomainsUserCount"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAllDomainsUserCount",
      "getAllDomainsUserCount",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "numUsers", ["::SOAP::SOAPInt"]],
        [:retval, "numUsers", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAllDomainsMXRecords"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAllDomainsMXRecords",
      "getAllDomainsMXRecords",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "MxRecordArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "MxRecordArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetNobodyAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetNobodyAlias",
      "setNobodyAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveNobodyAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveNobodyAlias",
      "removeNobodyAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsers"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsers",
      "getDomainUsers",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersString",
      "getDomainUsersString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersStringAlpha"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersStringAlpha",
      "getDomainUsersStringAlpha",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "indexChar", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPString"]],
        [:in, "UserArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersSpamStatusString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersSpamStatusString",
      "getDomainUsersSpamStatusString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersSafeListStatusString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersSafeListStatusString",
      "getDomainUsersSafeListStatusString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersBlackListStatusString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersBlackListStatusString",
      "getDomainUsersBlackListStatusString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "CheckUserExists"),
      "http://admin.excedent.com/mailaccounts/action/Utils.CheckUserExists",
      "checkUserExists",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUser"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUser",
      "addUser",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "FirstName", ["::SOAP::SOAPString"]],
        [:in, "LastName", ["::SOAP::SOAPString"]],
        [:in, "StreetAddress", ["::SOAP::SOAPString"]],
        [:in, "City", ["::SOAP::SOAPString"]],
        [:in, "State", ["::SOAP::SOAPString"]],
        [:in, "Country", ["::SOAP::SOAPString"]],
        [:in, "PostalCode", ["::SOAP::SOAPString"]],
        [:in, "Telephone", ["::SOAP::SOAPString"]],
        [:in, "Organization", ["::SOAP::SOAPString"]],
        [:in, "Department", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUser"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUser",
      "deleteUser",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyUser"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyUser",
      "modifyUser",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "FirstName", ["::SOAP::SOAPString"]],
        [:in, "LastName", ["::SOAP::SOAPString"]],
        [:in, "StreetAddress", ["::SOAP::SOAPString"]],
        [:in, "City", ["::SOAP::SOAPString"]],
        [:in, "State", ["::SOAP::SOAPString"]],
        [:in, "Country", ["::SOAP::SOAPString"]],
        [:in, "PostalCode", ["::SOAP::SOAPString"]],
        [:in, "Telephone", ["::SOAP::SOAPString"]],
        [:in, "Organization", ["::SOAP::SOAPString"]],
        [:in, "Department", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyUserPassword"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyUserPassword",
      "modifyUserPassword",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ChangeUserPassword"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ChangeUserPassword",
      "changeUserPassword",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "OldPassword", ["::SOAP::SOAPString"]],
        [:in, "NewPassword", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserAttributes"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserAttributes",
      "getUserAttributes",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "attributeString", ["::SOAP::SOAPString"]],
        [:retval, "attributeString", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUsersWithFilterStr"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUsersWithFilterStr",
      "getUsersWithFilterStr",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "filterStr", ["::SOAP::SOAPString"]],
        [:in, "UsersStr", ["::SOAP::SOAPString"]],
        [:retval, "UsersStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserMailForward"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserMailForward",
      "getUserMailForward",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "ForwardEmailString", ["::SOAP::SOAPString"]],
        [:in, "SaveCopy", ["::SOAP::SOAPShort"]],
        [:retval, "ForwardEmailString", ["::SOAP::SOAPString"]],
        [:out, "SaveCopy", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserMailForward"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserMailForward",
      "setUserMailForward",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "ForwardEmailString", ["::SOAP::SOAPString"]],
        [:in, "SaveCopy", ["::SOAP::SOAPShort"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveUserMailForward"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveUserMailForward",
      "removeUserMailForward",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserMailVacation"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserMailVacation",
      "getUserMailVacation",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "VacationMsg", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "VacationMsg", ["::SOAP::SOAPString"]],
        [:out, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserMailVacation"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserMailVacation",
      "setUserMailVacation",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "VacationMsg", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserMailboxMaxSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserMailboxMaxSize",
      "setUserMailboxMaxSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "MaxMbxSize", ["::SOAP::SOAPInt"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserMailboxMaxSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserMailboxMaxSize",
      "getUserMailboxMaxSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "MaxMbxSize", ["::SOAP::SOAPDouble"]],
        [:retval, "MaxMbxSize", ["::SOAP::SOAPDouble"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserLastLogin"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserLastLogin",
      "getUserLastLogin",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "lastlogin", ["::SOAP::SOAPString"]],
        [:retval, "lastlogin", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserActiveStatus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserActiveStatus",
      "getUserActiveStatus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserStatus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserStatus",
      "getUserStatus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetCurrentUserMailboxSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetCurrentUserMailboxSize",
      "getCurrentUserMailboxSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "CurrentMbxSize", ["::SOAP::SOAPDouble"]],
        [:retval, "CurrentMbxSize", ["::SOAP::SOAPDouble"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserLastLogin"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserLastLogin",
      "getDomainAllUserLastLogin",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserCurrentSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserCurrentSize",
      "getDomainAllUserCurrentSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserStats"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserStats",
      "getDomainAllUserStats",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserLastLoginActive"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserLastLoginActive",
      "getDomainAllUserLastLoginActive",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPShort"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserCurrentSizeActive"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserCurrentSizeActive",
      "getDomainAllUserCurrentSizeActive",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPShort"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserStatsActive"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserStatsActive",
      "getDomainAllUserStatsActive",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPShort"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserStatsActiveString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserStatsActiveString",
      "getDomainAllUserStatsActiveString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Active", ["::SOAP::SOAPShort"]],
        [:in, "UserStatArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "UserStatArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUsersForward"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUsersForward",
      "getDomainAllUsersForward",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserForwardArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserForwardArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "CheckAliasExists"),
      "http://admin.excedent.com/mailaccounts/action/Utils.CheckAliasExists",
      "checkAliasExists",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "CheckUserAvailable"),
      "http://admin.excedent.com/mailaccounts/action/Utils.CheckUserAvailable",
      "checkUserAvailable",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserAliasesString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserAliasesString",
      "getUserAliasesString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Aliases", ["::SOAP::SOAPString"]],
        [:retval, "Aliases", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserAliasesStringAlpha"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserAliasesStringAlpha",
      "getUserAliasesStringAlpha",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "indexChar", ["::SOAP::SOAPString"]],
        [:in, "Aliases", ["::SOAP::SOAPString"]],
        [:retval, "Aliases", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetGroupAliasesString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetGroupAliasesString",
      "getGroupAliasesString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Aliases", ["::SOAP::SOAPString"]],
        [:retval, "Aliases", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddAlias",
      "addAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddGroupAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddGroupAlias",
      "addGroupAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyAlias",
      "modifyAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyGroupAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyGroupAlias",
      "modifyGroupAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteAlias",
      "deleteAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetAliasSingleAddress"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetAliasSingleAddress",
      "setAliasSingleAddress",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "Action", ["::SOAP::SOAPString"]],
        [:in, "email", ["::SOAP::SOAPString"]],
        [:retval, "email", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetAlias"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetAlias",
      "getAlias",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Alias", ["::SOAP::SOAPString"]],
        [:in, "EmailString", ["::SOAP::SOAPString"]],
        [:retval, "EmailString", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetListUsers"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetListUsers",
      "getListUsers",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "ListName", ["::SOAP::SOAPString"]],
        [:in, "Users", ["::SOAP::SOAPString"]],
        [:retval, "Users", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetListUsers"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetListUsers",
      "setListUsers",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "ListName", ["::SOAP::SOAPString"]],
        [:in, "Users", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainNotify"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainNotify",
      "setDomainNotify",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "NotifyPercentage", ["::SOAP::SOAPString"]],
        [:in, "ccEmail", ["::SOAP::SOAPString"]],
        [:in, "NotifyMessage", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainNotify"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainNotify",
      "getDomainNotify",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "NotifyPercentage", ["::SOAP::SOAPString"]],
        [:in, "ccEmail", ["::SOAP::SOAPString"]],
        [:in, "NotifyMessage", ["::SOAP::SOAPString"]],
        [:retval, "NotifyPercentage", ["::SOAP::SOAPString"]],
        [:out, "ccEmail", ["::SOAP::SOAPString"]],
        [:out, "NotifyMessage", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SendMailDomainUsersAll"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SendMailDomainUsersAll",
      "sendMailDomainUsersAll",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "MailFromName", ["::SOAP::SOAPString"]],
        [:in, "MailReplyTo", ["::SOAP::SOAPString"]],
        [:in, "MailSubject", ["::SOAP::SOAPString"]],
        [:in, "MailBody", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUsersBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUsersBulk",
      "addUsersBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyUsersBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyUsersBulk",
      "modifyUsersBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUsersBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUsersBulk",
      "deleteUsersBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUsersActiveBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUsersActiveBulk",
      "setUsersActiveBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserAliasesBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserAliasesBulk",
      "getUserAliasesBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserAliasesBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserAliasesBulk",
      "addUserAliasesBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUserAliasesBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUserAliasesBulk",
      "deleteUserAliasesBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "aliasesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserWithLdapAttributes"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserWithLdapAttributes",
      "addUserWithLdapAttributes",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Surname", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "AttributesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "AttributesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserWithLdapAttributesString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserWithLdapAttributesString",
      "addUserWithLdapAttributesString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Surname", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "AttributesArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "AttributesArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyUserWithLdapAttributes"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyUserWithLdapAttributes",
      "modifyUserWithLdapAttributes",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Surname", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "AttributesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "AttributesArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ModifyUserWithLdapAttributesString"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ModifyUserWithLdapAttributesString",
      "modifyUserWithLdapAttributesString",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Surname", ["::SOAP::SOAPString"]],
        [:in, "Password", ["::SOAP::SOAPString"]],
        [:in, "SetActive", ["::SOAP::SOAPShort"]],
        [:in, "AttributesArrayStr", ["::SOAP::SOAPString"]],
        [:retval, "AttributesArrayStr", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainVirus",
      "addDomainVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteDomainVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteDomainVirus",
      "deleteDomainVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainVirus",
      "getDomainVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserVirus",
      "addUserVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUserVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUserVirus",
      "deleteUserVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserVirus"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserVirus",
      "getUserVirus",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserVirusBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserVirusBulk",
      "addUserVirusBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUserVirusBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUserVirusBulk",
      "deleteUserVirusBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserVirusBulk"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserVirusBulk",
      "getUserVirusBulk",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainSpam",
      "addDomainSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "FilterLevel", ["::SOAP::SOAPString"]],
        [:in, "Action", ["::SOAP::SOAPString"]],
        [:in, "ActionValue", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteDomainSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteDomainSpam",
      "deleteDomainSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpam",
      "getDomainSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "FilterLevel", ["::SOAP::SOAPString"]],
        [:in, "Action", ["::SOAP::SOAPString"]],
        [:in, "ActionValue", ["::SOAP::SOAPString"]],
        [:retval, "FilterLevel", ["::SOAP::SOAPString"]],
        [:out, "Action", ["::SOAP::SOAPString"]],
        [:out, "ActionValue", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserSpam",
      "addUserSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "FilterLevel", ["::SOAP::SOAPString"]],
        [:in, "Action", ["::SOAP::SOAPString"]],
        [:in, "ActionValue", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "DeleteUserSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.DeleteUserSpam",
      "deleteUserSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpam"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpam",
      "getUserSpam",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "FilterLevel", ["::SOAP::SOAPString"]],
        [:in, "Action", ["::SOAP::SOAPString"]],
        [:in, "ActionValue", ["::SOAP::SOAPString"]],
        [:retval, "FilterLevel", ["::SOAP::SOAPString"]],
        [:out, "Action", ["::SOAP::SOAPString"]],
        [:out, "ActionValue", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamCleaner"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamCleaner",
      "setDomainSpamCleaner",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "NumDays", ["::SOAP::SOAPShort"]],
        [:in, "NumEmails", ["::SOAP::SOAPShort"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamCleaner"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamCleaner",
      "getDomainSpamCleaner",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "NumDays", ["::SOAP::SOAPShort"]],
        [:in, "NumEmails", ["::SOAP::SOAPShort"]],
        [:retval, "NumDays", ["::SOAP::SOAPShort"]],
        [:out, "NumEmails", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamCleaner"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamCleaner",
      "setUserSpamCleaner",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "NumDays", ["::SOAP::SOAPShort"]],
        [:in, "NumEmails", ["::SOAP::SOAPShort"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamCleaner"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamCleaner",
      "getUserSpamCleaner",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "NumDays", ["::SOAP::SOAPShort"]],
        [:in, "NumEmails", ["::SOAP::SOAPShort"]],
        [:retval, "NumDays", ["::SOAP::SOAPShort"]],
        [:out, "NumEmails", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamSafeList",
      "setDomainSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamIPSafeList",
      "setDomainSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamSafeList",
      "getDomainSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "SafeList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamIPSafeList",
      "getDomainSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "SafeList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamSafeList",
      "setUserSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamIPSafeList",
      "setUserSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamSafeList",
      "getUserSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "SafeList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamIPSafeList",
      "getUserSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeList", ["::SOAP::SOAPString"]],
        [:retval, "SafeList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamBlackList",
      "setDomainSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamIPBlackList",
      "setDomainSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamBlackList",
      "getDomainSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "BlackList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamIPBlackList",
      "getDomainSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "BlackList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamBlackList",
      "setUserSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamIPBlackList",
      "setUserSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamBlackList",
      "getUserSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "BlackList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamIPBlackList",
      "getUserSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackList", ["::SOAP::SOAPString"]],
        [:retval, "BlackList", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainSpamSafeList",
      "addDomainSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainSpamIPSafeList",
      "addDomainSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "SafeListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainSpamBlackList",
      "addDomainSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddDomainSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddDomainSpamIPBlackList",
      "addDomainSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserSpamSafeList",
      "addUserSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserSpamIPSafeList",
      "addUserSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "SafeListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserSpamBlackList",
      "addUserSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "AddUserSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.AddUserSpamIPBlackList",
      "addUserSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveDomainSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveDomainSpamSafeList",
      "removeDomainSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveDomainSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveDomainSpamIPSafeList",
      "removeDomainSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "SafeListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveDomainSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveDomainSpamBlackList",
      "removeDomainSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveDomainSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveDomainSpamIPBlackList",
      "removeDomainSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveUserSpamSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveUserSpamSafeList",
      "removeUserSpamSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "Result", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveUserSpamIPSafeList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveUserSpamIPSafeList",
      "removeUserSpamIPSafeList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "SafeListEntries", ["::SOAP::SOAPString"]],
        [:retval, "SafeListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveUserSpamBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveUserSpamBlackList",
      "removeUserSpamBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "RemoveUserSpamIPBlackList"),
      "http://admin.excedent.com/mailaccounts/action/Utils.RemoveUserSpamIPBlackList",
      "removeUserSpamIPBlackList",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "BlackListEntries", ["::SOAP::SOAPString"]],
        [:retval, "BlackListEntries", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainSpamGreylist"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainSpamGreylist",
      "setDomainSpamGreylist",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainSpamGreylist"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainSpamGreylist",
      "getDomainSpamGreylist",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetUserSpamGreylist"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetUserSpamGreylist",
      "setUserSpamGreylist",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetUserSpamGreylist"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetUserSpamGreylist",
      "getUserSpamGreylist",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UserID", ["::SOAP::SOAPString"]],
        [:in, "Enabled", ["::SOAP::SOAPShort"]],
        [:retval, "Enabled", ["::SOAP::SOAPShort"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetMailAllotStorage"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetMailAllotStorage",
      "getMailAllotStorage",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "TotalAllotExtraStorage", ["::SOAP::SOAPInt"]],
        [:retval, "TotalAllotExtraStorage", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainUsersMailboxMaxSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainUsersMailboxMaxSize",
      "getDomainUsersMailboxMaxSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "TotalAllotExtraStorage", ["::SOAP::SOAPInt"]],
        [:in, "TotalAllocatedExtraStorage", ["::SOAP::SOAPInt"]],
        [:in, "HostMailboxMaxSize", ["::SOAP::SOAPInt"]],
        [:in, "UsersMailboxMaxSizeString", ["::SOAP::SOAPString"]],
        [:retval, "TotalAllotExtraStorage", ["::SOAP::SOAPInt"]],
        [:out, "TotalAllocatedExtraStorage", ["::SOAP::SOAPInt"]],
        [:out, "HostMailboxMaxSize", ["::SOAP::SOAPInt"]],
        [:out, "UsersMailboxMaxSizeString", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "SetDomainUsersMailboxMaxSize"),
      "http://admin.excedent.com/mailaccounts/action/Utils.SetDomainUsersMailboxMaxSize",
      "setDomainUsersMailboxMaxSize",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "UsersMailboxMaxSizeString", ["::SOAP::SOAPString"]],
        [:retval, "UsersMailboxMaxSizeString", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserLastLoginAlpha"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserLastLoginAlpha",
      "getDomainAllUserLastLoginAlpha",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "indexLetter", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserCurrentSizeAlpha"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserCurrentSizeAlpha",
      "getDomainAllUserCurrentSizeAlpha",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "indexLetter", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainAllUserStatsAlpha"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainAllUserStatsAlpha",
      "getDomainAllUserStatsAlpha",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "indexLetter", ["::SOAP::SOAPString"]],
        [:in, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]],
        [:retval, "UserStatArray", ["ArrayOfstring", "http://admin.excedent.com/mailaccounts/type/", "ArrayOfstring"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "ping"),
      "http://admin.excedent.com/mailaccounts/action/Utils.ping",
      "ping",
      [ [:in, "MyMessage", ["::SOAP::SOAPString"]],
        [:retval, "MyMessage", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetRetCodeDesc"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetRetCodeDesc",
      "getRetCodeDesc",
      [ [:in, "RetCode", ["::SOAP::SOAPShort"]],
        [:retval, "Result", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsMessage, "GetDomainNumBcc"),
      "http://admin.excedent.com/mailaccounts/action/Utils.GetDomainNumBcc",
      "getDomainNumBcc",
      [ [:in, "ResellerUsername", ["::SOAP::SOAPString"]],
        [:in, "ResellerPassword", ["::SOAP::SOAPString"]],
        [:in, "HostName", ["::SOAP::SOAPString"]],
        [:in, "numBcc", ["::SOAP::SOAPInt"]],
        [:retval, "numBcc", ["::SOAP::SOAPInt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = MailaccountsMappingRegistry::EncodedRegistry
    self.literal_mapping_registry = MailaccountsMappingRegistry::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end

